# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/destinations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*kaskada/kaskada/v1alpha/destinations.proto\x12\x17kaskada.kaskada.v1alpha\"\xf1\x01\n\x16ObjectStoreDestination\x12R\n\x06\x66ormat\x18\x01 \x01(\x0e\x32:.kaskada.kaskada.v1alpha.ObjectStoreDestination.FileFormatR\x06\x66ormat\x12*\n\x11output_prefix_uri\x18\x02 \x01(\tR\x0foutputPrefixUri\"W\n\nFileFormat\x12\x1b\n\x17\x46ILE_FORMAT_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46ILE_FORMAT_PARQUET\x10\x01\x12\x13\n\x0f\x46ILE_FORMAT_CSV\x10\x02\"\xa7\x02\n\x10RedisDestination\x12\x1b\n\thost_name\x18\x01 \x01(\tR\x08hostName\x12\x12\n\x04port\x18\x02 \x01(\x05R\x04port\x12\x17\n\x07use_tls\x18\x03 \x01(\x08R\x06useTls\x12\'\n\x0f\x64\x61tabase_number\x18\x04 \x01(\x05R\x0e\x64\x61tabaseNumber\x12\x1a\n\x08password\x18\x05 \x01(\tR\x08password\x12\x19\n\x08tls_cert\x18\x06 \x01(\tR\x07tlsCert\x12\x17\n\x07tls_key\x18\x07 \x01(\tR\x06tlsKey\x12\x1e\n\x0btls_ca_cert\x18\x08 \x01(\tR\ttlsCaCert\x12\x30\n\x14insecure_skip_verify\x18\t \x01(\x08R\x12insecureSkipVerifyB\x81\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x11\x44\x65stinationsProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_OBJECTSTOREDESTINATION = DESCRIPTOR.message_types_by_name['ObjectStoreDestination']
_REDISDESTINATION = DESCRIPTOR.message_types_by_name['RedisDestination']
_OBJECTSTOREDESTINATION_FILEFORMAT = _OBJECTSTOREDESTINATION.enum_types_by_name['FileFormat']
ObjectStoreDestination = _reflection.GeneratedProtocolMessageType('ObjectStoreDestination', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTSTOREDESTINATION,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ObjectStoreDestination)
  })
_sym_db.RegisterMessage(ObjectStoreDestination)

RedisDestination = _reflection.GeneratedProtocolMessageType('RedisDestination', (_message.Message,), {
  'DESCRIPTOR' : _REDISDESTINATION,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.RedisDestination)
  })
_sym_db.RegisterMessage(RedisDestination)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\021DestinationsProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _OBJECTSTOREDESTINATION._serialized_start=72
  _OBJECTSTOREDESTINATION._serialized_end=313
  _OBJECTSTOREDESTINATION_FILEFORMAT._serialized_start=226
  _OBJECTSTOREDESTINATION_FILEFORMAT._serialized_end=313
  _REDISDESTINATION._serialized_start=316
  _REDISDESTINATION._serialized_end=611
# @@protoc_insertion_point(module_scope)
