# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/query_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2
from kaskada.kaskada.v1alpha import view_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_view__service__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+kaskada/kaskada/v1alpha/query_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a.kaskada/kaskada/v1alpha/fenl_diagnostics.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\x1a*kaskada/kaskada/v1alpha/view_service.proto\x1a\x17validate/validate.proto\"\xec\x08\n\x05Query\x12\x1e\n\x08query_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07queryId\x12\'\n\nexpression\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12=\n\x08\x61s_files\x18\x65 \x01(\x0b\x32 .kaskada.kaskada.v1alpha.AsFilesH\x00R\x07\x61sFiles\x12\x44\n\tredis_a_i\x18\x66 \x01(\x0b\x32&.kaskada.kaskada.v1alpha.Query.RedisAIH\x00R\x07redisAI\x12@\n\rdata_token_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x61taTokenId\x12\x38\n\x05views\x18\x04 \x03(\x0b\x32\x1d.kaskada.kaskada.v1alpha.ViewB\x03\xe0\x41\x03R\x05views\x12V\n\x0fresult_behavior\x18\x05 \x01(\x0e\x32-.kaskada.kaskada.v1alpha.Query.ResultBehaviorR\x0eresultBehavior\x12=\n\x06limits\x18\x06 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.Query.LimitsR\x06limits\x12;\n\x05slice\x18\x07 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x05slice\x12H\n\x12\x63hanged_since_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x63hangedSinceTime\x12\x46\n\x11\x66inal_result_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inalResultTime\x12@\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x1a+\n\x06Limits\x12!\n\x0cpreview_rows\x18\x01 \x01(\x03R\x0bpreviewRows\x1a)\n\x11RedisBulkResponse\x12\x14\n\x05shape\x18\x01 \x03(\x05R\x05shape\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04port\"\xa0\x01\n\x0eResultBehavior\x12\x1f\n\x1bRESULT_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1f\n\x1bRESULT_BEHAVIOR_ALL_RESULTS\x10\x01\x12!\n\x1dRESULT_BEHAVIOR_FINAL_RESULTS\x10\x02\x12)\n%RESULT_BEHAVIOR_FINAL_RESULTS_AT_TIME\x10\x03\x42\x12\n\x0bresponse_as\x12\x03\xf8\x42\x01\"\xac\x01\n\x0cQueryOptions\x12\x17\n\x07\x64ry_run\x18\x01 \x01(\x08R\x06\x64ryRun\x12\x33\n\x15\x65xperimental_features\x18\x02 \x01(\x08R\x14\x65xperimentalFeatures\x12%\n\x0estream_metrics\x18\x03 \x01(\x08R\rstreamMetrics\x12\'\n\x0fpresign_results\x18\x04 \x01(\x08R\x0epresignResults\"\x96\x01\n\x12\x43reateQueryRequest\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v1alpha.QueryR\x05query\x12J\n\rquery_options\x18\x02 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.QueryOptionsR\x0cqueryOptions\"\xec\n\n\x13\x43reateQueryResponse\x12H\n\x05state\x18\x01 \x01(\x0e\x32\x32.kaskada.kaskada.v1alpha.CreateQueryResponse.StateR\x05state\x12K\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x33.kaskada.kaskada.v1alpha.CreateQueryResponse.ConfigR\x06\x63onfig\x12Q\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x35.kaskada.kaskada.v1alpha.CreateQueryResponse.AnalysisR\x08\x61nalysis\x12S\n\x10\x66\x65nl_diagnostics\x18\x04 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12N\n\x07metrics\x18\x05 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.CreateQueryResponse.MetricsR\x07metrics\x12P\n\x0frequest_details\x18\x06 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\x12\x19\n\x08query_id\x18\x07 \x01(\tR\x07queryId\x12I\n\x0c\x66ile_results\x18\x65 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.FileResultsH\x00R\x0b\x66ileResults\x12R\n\tredis_a_i\x18\x66 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.CreateQueryResponse.RedisAIH\x00R\x07redisAI\x1a\x64\n\x08\x41nalysis\x12\x1f\n\x0b\x63\x61n_execute\x18\x01 \x01(\x08R\ncanExecute\x12\x37\n\x06schema\x18\x02 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaR\x06schema\x1ax\n\x06\x43onfig\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12J\n\rslice_request\x18\x02 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x0csliceRequest\x1a\xbe\x02\n\x07Metrics\x12@\n\x0etime_preparing\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtimePreparing\x12@\n\x0etime_computing\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtimeComputing\x12!\n\x0coutput_files\x18\x03 \x01(\x03R\x0boutputFiles\x12(\n\x10total_input_rows\x18\x04 \x01(\x03R\x0etotalInputRows\x12\x30\n\x14processed_input_rows\x18\x05 \x01(\x03R\x12processedInputRows\x12\x30\n\x14produced_output_rows\x18\x06 \x01(\x03R\x12producedOutputRows\x1a\t\n\x07RedisAI\"\x82\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_ANALYSIS\x10\x01\x12\x13\n\x0fSTATE_PREPARING\x10\x02\x12\x13\n\x0fSTATE_COMPUTING\x10\x03\x12\x11\n\rSTATE_SUCCESS\x10\x04\x12\x11\n\rSTATE_FAILURE\x10\x05\x42\t\n\x07results\"5\n\x0fGetQueryRequest\x12\"\n\x08query_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07queryId\"M\n\x10GetQueryResponse\x12\x39\n\x05query\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v1alpha.QueryB\x03\xe0\x41\x03R\x05query\"t\n\x12ListQueriesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc9\x01\n\x13ListQueriesResponse\x12\x38\n\x07queries\x18\x01 \x03(\x0b\x32\x1e.kaskada.kaskada.v1alpha.QueryR\x07queries\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12P\n\x0frequest_details\x18\x03 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails2\xaa\x03\n\x0cQueryService\x12\x8b\x01\n\x0b\x43reateQuery\x12+.kaskada.kaskada.v1alpha.CreateQueryRequest\x1a,.kaskada.kaskada.v1alpha.CreateQueryResponse\"\x1f\x82\xd3\xe4\x93\x02\x19:\x05query\"\x10/v1alpha/queries0\x01\x12\x86\x01\n\x08GetQuery\x12(.kaskada.kaskada.v1alpha.GetQueryRequest\x1a).kaskada.kaskada.v1alpha.GetQueryResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1alpha/queries/{query_id=*}\x12\x82\x01\n\x0bListQueries\x12+.kaskada.kaskada.v1alpha.ListQueriesRequest\x1a,.kaskada.kaskada.v1alpha.ListQueriesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1alpha/queriesB\x81\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x11QueryServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_QUERY = DESCRIPTOR.message_types_by_name['Query']
_QUERY_LIMITS = _QUERY.nested_types_by_name['Limits']
_QUERY_REDISBULKRESPONSE = _QUERY.nested_types_by_name['RedisBulkResponse']
_QUERY_REDISAI = _QUERY.nested_types_by_name['RedisAI']
_QUERYOPTIONS = DESCRIPTOR.message_types_by_name['QueryOptions']
_CREATEQUERYREQUEST = DESCRIPTOR.message_types_by_name['CreateQueryRequest']
_CREATEQUERYRESPONSE = DESCRIPTOR.message_types_by_name['CreateQueryResponse']
_CREATEQUERYRESPONSE_ANALYSIS = _CREATEQUERYRESPONSE.nested_types_by_name['Analysis']
_CREATEQUERYRESPONSE_CONFIG = _CREATEQUERYRESPONSE.nested_types_by_name['Config']
_CREATEQUERYRESPONSE_METRICS = _CREATEQUERYRESPONSE.nested_types_by_name['Metrics']
_CREATEQUERYRESPONSE_REDISAI = _CREATEQUERYRESPONSE.nested_types_by_name['RedisAI']
_GETQUERYREQUEST = DESCRIPTOR.message_types_by_name['GetQueryRequest']
_GETQUERYRESPONSE = DESCRIPTOR.message_types_by_name['GetQueryResponse']
_LISTQUERIESREQUEST = DESCRIPTOR.message_types_by_name['ListQueriesRequest']
_LISTQUERIESRESPONSE = DESCRIPTOR.message_types_by_name['ListQueriesResponse']
_QUERY_RESULTBEHAVIOR = _QUERY.enum_types_by_name['ResultBehavior']
_CREATEQUERYRESPONSE_STATE = _CREATEQUERYRESPONSE.enum_types_by_name['State']
Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {

  'Limits' : _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_LIMITS,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query.Limits)
    })
  ,

  'RedisBulkResponse' : _reflection.GeneratedProtocolMessageType('RedisBulkResponse', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_REDISBULKRESPONSE,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query.RedisBulkResponse)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_REDISAI,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query.RedisAI)
    })
  ,
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query)
  })
_sym_db.RegisterMessage(Query)
_sym_db.RegisterMessage(Query.Limits)
_sym_db.RegisterMessage(Query.RedisBulkResponse)
_sym_db.RegisterMessage(Query.RedisAI)

QueryOptions = _reflection.GeneratedProtocolMessageType('QueryOptions', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOPTIONS,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.QueryOptions)
  })
_sym_db.RegisterMessage(QueryOptions)

CreateQueryRequest = _reflection.GeneratedProtocolMessageType('CreateQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUERYREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryRequest)
  })
_sym_db.RegisterMessage(CreateQueryRequest)

CreateQueryResponse = _reflection.GeneratedProtocolMessageType('CreateQueryResponse', (_message.Message,), {

  'Analysis' : _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_ANALYSIS,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.Analysis)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_CONFIG,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.Config)
    })
  ,

  'Metrics' : _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_METRICS,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.Metrics)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_REDISAI,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.RedisAI)
    })
  ,
  'DESCRIPTOR' : _CREATEQUERYRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse)
  })
_sym_db.RegisterMessage(CreateQueryResponse)
_sym_db.RegisterMessage(CreateQueryResponse.Analysis)
_sym_db.RegisterMessage(CreateQueryResponse.Config)
_sym_db.RegisterMessage(CreateQueryResponse.Metrics)
_sym_db.RegisterMessage(CreateQueryResponse.RedisAI)

GetQueryRequest = _reflection.GeneratedProtocolMessageType('GetQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetQueryRequest)
  })
_sym_db.RegisterMessage(GetQueryRequest)

GetQueryResponse = _reflection.GeneratedProtocolMessageType('GetQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetQueryResponse)
  })
_sym_db.RegisterMessage(GetQueryResponse)

ListQueriesRequest = _reflection.GeneratedProtocolMessageType('ListQueriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListQueriesRequest)
  })
_sym_db.RegisterMessage(ListQueriesRequest)

ListQueriesResponse = _reflection.GeneratedProtocolMessageType('ListQueriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListQueriesResponse)
  })
_sym_db.RegisterMessage(ListQueriesResponse)

_QUERYSERVICE = DESCRIPTOR.services_by_name['QueryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\021QueryServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _QUERY_REDISAI.fields_by_name['db']._options = None
  _QUERY_REDISAI.fields_by_name['db']._serialized_options = b'\372B\006\032\004\030\017(\000'
  _QUERY_REDISAI.fields_by_name['host']._options = None
  _QUERY_REDISAI.fields_by_name['host']._serialized_options = b'\372B\004r\002\020\001'
  _QUERY_REDISAI.fields_by_name['port']._options = None
  _QUERY_REDISAI.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _QUERY.oneofs_by_name['response_as']._options = None
  _QUERY.oneofs_by_name['response_as']._serialized_options = b'\370B\001'
  _QUERY.fields_by_name['query_id']._options = None
  _QUERY.fields_by_name['query_id']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['expression']._options = None
  _QUERY.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _QUERY.fields_by_name['views']._options = None
  _QUERY.fields_by_name['views']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['create_time']._options = None
  _QUERY.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _GETQUERYREQUEST.fields_by_name['query_id']._options = None
  _GETQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETQUERYRESPONSE.fields_by_name['query']._options = None
  _GETQUERYRESPONSE.fields_by_name['query']._serialized_options = b'\340A\003'
  _LISTQUERIESREQUEST.fields_by_name['page_size']._options = None
  _LISTQUERIESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _QUERYSERVICE.methods_by_name['CreateQuery']._options = None
  _QUERYSERVICE.methods_by_name['CreateQuery']._serialized_options = b'\202\323\344\223\002\031:\005query\"\020/v1alpha/queries'
  _QUERYSERVICE.methods_by_name['GetQuery']._options = None
  _QUERYSERVICE.methods_by_name['GetQuery']._serialized_options = b'\202\323\344\223\002\037\022\035/v1alpha/queries/{query_id=*}'
  _QUERYSERVICE.methods_by_name['ListQueries']._options = None
  _QUERYSERVICE.methods_by_name['ListQueries']._serialized_options = b'\202\323\344\223\002\022\022\020/v1alpha/queries'
  _QUERY._serialized_start=426
  _QUERY._serialized_end=1558
  _QUERY_LIMITS._serialized_start=1189
  _QUERY_LIMITS._serialized_end=1232
  _QUERY_REDISBULKRESPONSE._serialized_start=1234
  _QUERY_REDISBULKRESPONSE._serialized_end=1275
  _QUERY_REDISAI._serialized_start=1277
  _QUERY_REDISAI._serialized_end=1375
  _QUERY_RESULTBEHAVIOR._serialized_start=1378
  _QUERY_RESULTBEHAVIOR._serialized_end=1538
  _QUERYOPTIONS._serialized_start=1561
  _QUERYOPTIONS._serialized_end=1733
  _CREATEQUERYREQUEST._serialized_start=1736
  _CREATEQUERYREQUEST._serialized_end=1886
  _CREATEQUERYRESPONSE._serialized_start=1889
  _CREATEQUERYRESPONSE._serialized_end=3277
  _CREATEQUERYRESPONSE_ANALYSIS._serialized_start=2579
  _CREATEQUERYRESPONSE_ANALYSIS._serialized_end=2679
  _CREATEQUERYRESPONSE_CONFIG._serialized_start=2681
  _CREATEQUERYRESPONSE_CONFIG._serialized_end=2801
  _CREATEQUERYRESPONSE_METRICS._serialized_start=2804
  _CREATEQUERYRESPONSE_METRICS._serialized_end=3122
  _CREATEQUERYRESPONSE_REDISAI._serialized_start=1277
  _CREATEQUERYRESPONSE_REDISAI._serialized_end=1286
  _CREATEQUERYRESPONSE_STATE._serialized_start=3136
  _CREATEQUERYRESPONSE_STATE._serialized_end=3266
  _GETQUERYREQUEST._serialized_start=3279
  _GETQUERYREQUEST._serialized_end=3332
  _GETQUERYRESPONSE._serialized_start=3334
  _GETQUERYRESPONSE._serialized_end=3411
  _LISTQUERIESREQUEST._serialized_start=3413
  _LISTQUERIESREQUEST._serialized_end=3529
  _LISTQUERIESRESPONSE._serialized_start=3532
  _LISTQUERIESRESPONSE._serialized_end=3733
  _QUERYSERVICE._serialized_start=3736
  _QUERYSERVICE._serialized_end=4162
# @@protoc_insertion_point(module_scope)
