# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/preparation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1kaskada/kaskada/v1alpha/preparation_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a$kaskada/kaskada/v1alpha/common.proto\"\xa4\x02\n\x12PrepareDataRequest\x12>\n\tfile_path\x18\x01 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.FilePathR\x08\x66ilePath\x12<\n\x06\x63onfig\x18\x02 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.TableConfigR\x06\x63onfig\x12,\n\x12output_path_prefix\x18\x03 \x01(\tR\x10outputPathPrefix\x12\x1f\n\x0b\x66ile_prefix\x18\x04 \x01(\tR\nfilePrefix\x12\x41\n\nslice_plan\x18\x05 \x01(\x0b\x32\".kaskada.kaskada.v1alpha.SlicePlanR\tslicePlan\"|\n\x13PrepareDataResponse\x12\x17\n\x07prep_id\x18\x01 \x01(\x05R\x06prepId\x12L\n\x0eprepared_files\x18\x02 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.PreparedFileR\rpreparedFiles\"\x19\n\x17GetCurrentPrepIDRequest\"3\n\x18GetCurrentPrepIDResponse\x12\x17\n\x07prep_id\x18\x01 \x01(\x05R\x06prepId2\xf7\x01\n\x12PreparationService\x12h\n\x0bPrepareData\x12+.kaskada.kaskada.v1alpha.PrepareDataRequest\x1a,.kaskada.kaskada.v1alpha.PrepareDataResponse\x12w\n\x10GetCurrentPrepID\x12\x30.kaskada.kaskada.v1alpha.GetCurrentPrepIDRequest\x1a\x31.kaskada.kaskada.v1alpha.GetCurrentPrepIDResponseB\x87\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x17PreparationServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_PREPAREDATAREQUEST = DESCRIPTOR.message_types_by_name['PrepareDataRequest']
_PREPAREDATARESPONSE = DESCRIPTOR.message_types_by_name['PrepareDataResponse']
_GETCURRENTPREPIDREQUEST = DESCRIPTOR.message_types_by_name['GetCurrentPrepIDRequest']
_GETCURRENTPREPIDRESPONSE = DESCRIPTOR.message_types_by_name['GetCurrentPrepIDResponse']
PrepareDataRequest = _reflection.GeneratedProtocolMessageType('PrepareDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDATAREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.preparation_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PrepareDataRequest)
  })
_sym_db.RegisterMessage(PrepareDataRequest)

PrepareDataResponse = _reflection.GeneratedProtocolMessageType('PrepareDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDATARESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.preparation_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PrepareDataResponse)
  })
_sym_db.RegisterMessage(PrepareDataResponse)

GetCurrentPrepIDRequest = _reflection.GeneratedProtocolMessageType('GetCurrentPrepIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTPREPIDREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.preparation_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetCurrentPrepIDRequest)
  })
_sym_db.RegisterMessage(GetCurrentPrepIDRequest)

GetCurrentPrepIDResponse = _reflection.GeneratedProtocolMessageType('GetCurrentPrepIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTPREPIDRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.preparation_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetCurrentPrepIDResponse)
  })
_sym_db.RegisterMessage(GetCurrentPrepIDResponse)

_PREPARATIONSERVICE = DESCRIPTOR.services_by_name['PreparationService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\027PreparationServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _PREPAREDATAREQUEST._serialized_start=117
  _PREPAREDATAREQUEST._serialized_end=409
  _PREPAREDATARESPONSE._serialized_start=411
  _PREPAREDATARESPONSE._serialized_end=535
  _GETCURRENTPREPIDREQUEST._serialized_start=537
  _GETCURRENTPREPIDREQUEST._serialized_end=562
  _GETCURRENTPREPIDRESPONSE._serialized_start=564
  _GETCURRENTPREPIDRESPONSE._serialized_end=615
  _PREPARATIONSERVICE._serialized_start=618
  _PREPARATIONSERVICE._serialized_end=865
# @@protoc_insertion_point(module_scope)
