# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/file_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*kaskada/kaskada/v1alpha/file_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a$kaskada/kaskada/v1alpha/common.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\"G\n\x0c\x46ileMetadata\x12\x37\n\x06schema\x18\x01 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaR\x06schema\"V\n\x12GetMetadataRequest\x12@\n\nfile_paths\x18\x01 \x03(\x0b\x32!.kaskada.kaskada.v1alpha.FilePathR\tfilePaths\"c\n\x13GetMetadataResponse\x12L\n\x0e\x66ile_metadatas\x18\x01 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.FileMetadataR\rfileMetadatas\"\xb8\x01\n\x14MergeMetadataRequest\x12M\n\x0etable_metadata\x18\x01 \x01(\x0b\x32&.kaskada.kaskada.v1alpha.TableMetadataR\rtableMetadata\x12Q\n\x11new_file_metadata\x18\x02 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.FileMetadataR\x0fnewFileMetadata\"\x90\x02\n\x15MergeMetadataResponse\x12Z\n\x15merged_table_metadata\x18\x01 \x01(\x0b\x32&.kaskada.kaskada.v1alpha.TableMetadataR\x13mergedTableMetadata\x12h\n\x10new_file_results\x18\x02 \x03(\x0b\x32>.kaskada.kaskada.v1alpha.MergeMetadataResponse.FileMergeResultR\x0enewFileResults\x1a\x31\n\x0f\x46ileMergeResult\x12\x1e\n\ncompatible\x18\x01 \x01(\x08R\ncompatible2\xe7\x01\n\x0b\x46ileService\x12h\n\x0bGetMetadata\x12+.kaskada.kaskada.v1alpha.GetMetadataRequest\x1a,.kaskada.kaskada.v1alpha.GetMetadataResponse\x12n\n\rMergeMetadata\x12-.kaskada.kaskada.v1alpha.MergeMetadataRequest\x1a..kaskada.kaskada.v1alpha.MergeMetadataResponseB\x80\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x10\x46ileServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_FILEMETADATA = DESCRIPTOR.message_types_by_name['FileMetadata']
_GETMETADATAREQUEST = DESCRIPTOR.message_types_by_name['GetMetadataRequest']
_GETMETADATARESPONSE = DESCRIPTOR.message_types_by_name['GetMetadataResponse']
_MERGEMETADATAREQUEST = DESCRIPTOR.message_types_by_name['MergeMetadataRequest']
_MERGEMETADATARESPONSE = DESCRIPTOR.message_types_by_name['MergeMetadataResponse']
_MERGEMETADATARESPONSE_FILEMERGERESULT = _MERGEMETADATARESPONSE.nested_types_by_name['FileMergeResult']
FileMetadata = _reflection.GeneratedProtocolMessageType('FileMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FILEMETADATA,
  '__module__' : 'kaskada.kaskada.v1alpha.file_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FileMetadata)
  })
_sym_db.RegisterMessage(FileMetadata)

GetMetadataRequest = _reflection.GeneratedProtocolMessageType('GetMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATAREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.file_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetMetadataRequest)
  })
_sym_db.RegisterMessage(GetMetadataRequest)

GetMetadataResponse = _reflection.GeneratedProtocolMessageType('GetMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATARESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.file_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetMetadataResponse)
  })
_sym_db.RegisterMessage(GetMetadataResponse)

MergeMetadataRequest = _reflection.GeneratedProtocolMessageType('MergeMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _MERGEMETADATAREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.file_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.MergeMetadataRequest)
  })
_sym_db.RegisterMessage(MergeMetadataRequest)

MergeMetadataResponse = _reflection.GeneratedProtocolMessageType('MergeMetadataResponse', (_message.Message,), {

  'FileMergeResult' : _reflection.GeneratedProtocolMessageType('FileMergeResult', (_message.Message,), {
    'DESCRIPTOR' : _MERGEMETADATARESPONSE_FILEMERGERESULT,
    '__module__' : 'kaskada.kaskada.v1alpha.file_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.MergeMetadataResponse.FileMergeResult)
    })
  ,
  'DESCRIPTOR' : _MERGEMETADATARESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.file_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.MergeMetadataResponse)
  })
_sym_db.RegisterMessage(MergeMetadataResponse)
_sym_db.RegisterMessage(MergeMetadataResponse.FileMergeResult)

_FILESERVICE = DESCRIPTOR.services_by_name['FileService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\020FileServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _FILEMETADATA._serialized_start=147
  _FILEMETADATA._serialized_end=218
  _GETMETADATAREQUEST._serialized_start=220
  _GETMETADATAREQUEST._serialized_end=306
  _GETMETADATARESPONSE._serialized_start=308
  _GETMETADATARESPONSE._serialized_end=407
  _MERGEMETADATAREQUEST._serialized_start=410
  _MERGEMETADATAREQUEST._serialized_end=594
  _MERGEMETADATARESPONSE._serialized_start=597
  _MERGEMETADATARESPONSE._serialized_end=869
  _MERGEMETADATARESPONSE_FILEMERGERESULT._serialized_start=820
  _MERGEMETADATARESPONSE_FILEMERGERESULT._serialized_end=869
  _FILESERVICE._serialized_start=872
  _FILESERVICE._serialized_end=1103
# @@protoc_insertion_point(module_scope)
