# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/table_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+kaskada/kaskada/v1alpha/table_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\x80\x06\n\x05Table\x12\x1e\n\x08table_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07tableId\x12&\n\ntable_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x31\n\x10time_column_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0etimeColumnName\x12<\n\x16\x65ntity_key_column_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13\x65ntityKeyColumnName\x12U\n\x13subsort_column_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x07\xfa\x42\x04r\x02\x10\x01R\x11subsortColumnName\x12\x1f\n\x0bgrouping_id\x18\x06 \x01(\tR\ngroupingId\x12@\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x1d\n\x07version\x18\t \x01(\x03\x42\x03\xe0\x41\x03R\x07version\x12<\n\x06schema\x18\n \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\x12\"\n\nfile_count\x18\x0b \x01(\x03\x42\x03\xe0\x41\x03R\tfileCount\x12M\n\x0ctable_source\x18\x0c \x01(\x0b\x32*.kaskada.kaskada.v1alpha.Table.TableSourceR\x0btableSource\x1a\x61\n\x0bTableSource\x12H\n\x07kaskada\x18\x01 \x01(\x0b\x32,.kaskada.kaskada.v1alpha.Table.KaskadaSourceH\x00R\x07kaskadaB\x08\n\x06source\x1a\x0f\n\rKaskadaSource\"s\n\x11ListTablesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc6\x01\n\x12ListTablesResponse\x12\x36\n\x06tables\x18\x01 \x03(\x0b\x32\x1e.kaskada.kaskada.v1alpha.TableR\x06tables\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12P\n\x0frequest_details\x18\x03 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"9\n\x0fGetTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\"\x9a\x01\n\x10GetTableResponse\x12\x34\n\x05table\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v1alpha.TableR\x05table\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"T\n\x12\x43reateTableRequest\x12>\n\x05table\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v1alpha.TableB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x05table\"\x9d\x01\n\x13\x43reateTableResponse\x12\x34\n\x05table\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v1alpha.TableR\x05table\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"R\n\x12\x44\x65leteTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\"\x8b\x01\n\x13\x44\x65leteTableResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"\x92\x01\n\x0fLoadDataRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x43\n\nfile_input\x18\x02 \x01(\x0b\x32\".kaskada.kaskada.v1alpha.FileInputH\x00R\tfileInputB\x12\n\x0bsource_data\x12\x03\xf8\x42\x01\"\x88\x01\n\x10LoadDataResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails2\xbe\x05\n\x0cTableService\x12~\n\nListTables\x12*.kaskada.kaskada.v1alpha.ListTablesRequest\x1a+.kaskada.kaskada.v1alpha.ListTablesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/tables\x12\x87\x01\n\x08GetTable\x12(.kaskada.kaskada.v1alpha.GetTableRequest\x1a).kaskada.kaskada.v1alpha.GetTableResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1alpha/tables/{table_name=*}\x12\x88\x01\n\x0b\x43reateTable\x12+.kaskada.kaskada.v1alpha.CreateTableRequest\x1a,.kaskada.kaskada.v1alpha.CreateTableResponse\"\x1e\x82\xd3\xe4\x93\x02\x18:\x05table\"\x0f/v1alpha/tables\x12\x90\x01\n\x0b\x44\x65leteTable\x12+.kaskada.kaskada.v1alpha.DeleteTableRequest\x1a,.kaskada.kaskada.v1alpha.DeleteTableResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1alpha/tables/{table_name=*}\x12\x85\x01\n\x08LoadData\x12(.kaskada.kaskada.v1alpha.LoadDataRequest\x1a).kaskada.kaskada.v1alpha.LoadDataResponse\"$\x82\xd3\xe4\x93\x02\x1e:\x01*\"\x19/v1alpha/tables/load_dataB\x81\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x11TableServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_TABLE = DESCRIPTOR.message_types_by_name['Table']
_TABLE_TABLESOURCE = _TABLE.nested_types_by_name['TableSource']
_TABLE_KASKADASOURCE = _TABLE.nested_types_by_name['KaskadaSource']
_LISTTABLESREQUEST = DESCRIPTOR.message_types_by_name['ListTablesRequest']
_LISTTABLESRESPONSE = DESCRIPTOR.message_types_by_name['ListTablesResponse']
_GETTABLEREQUEST = DESCRIPTOR.message_types_by_name['GetTableRequest']
_GETTABLERESPONSE = DESCRIPTOR.message_types_by_name['GetTableResponse']
_CREATETABLEREQUEST = DESCRIPTOR.message_types_by_name['CreateTableRequest']
_CREATETABLERESPONSE = DESCRIPTOR.message_types_by_name['CreateTableResponse']
_DELETETABLEREQUEST = DESCRIPTOR.message_types_by_name['DeleteTableRequest']
_DELETETABLERESPONSE = DESCRIPTOR.message_types_by_name['DeleteTableResponse']
_LOADDATAREQUEST = DESCRIPTOR.message_types_by_name['LoadDataRequest']
_LOADDATARESPONSE = DESCRIPTOR.message_types_by_name['LoadDataResponse']
Table = _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {

  'TableSource' : _reflection.GeneratedProtocolMessageType('TableSource', (_message.Message,), {
    'DESCRIPTOR' : _TABLE_TABLESOURCE,
    '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Table.TableSource)
    })
  ,

  'KaskadaSource' : _reflection.GeneratedProtocolMessageType('KaskadaSource', (_message.Message,), {
    'DESCRIPTOR' : _TABLE_KASKADASOURCE,
    '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Table.KaskadaSource)
    })
  ,
  'DESCRIPTOR' : _TABLE,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Table)
  })
_sym_db.RegisterMessage(Table)
_sym_db.RegisterMessage(Table.TableSource)
_sym_db.RegisterMessage(Table.KaskadaSource)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

CreateTableRequest = _reflection.GeneratedProtocolMessageType('CreateTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLEREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateTableRequest)
  })
_sym_db.RegisterMessage(CreateTableRequest)

CreateTableResponse = _reflection.GeneratedProtocolMessageType('CreateTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLERESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateTableResponse)
  })
_sym_db.RegisterMessage(CreateTableResponse)

DeleteTableRequest = _reflection.GeneratedProtocolMessageType('DeleteTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLEREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DeleteTableRequest)
  })
_sym_db.RegisterMessage(DeleteTableRequest)

DeleteTableResponse = _reflection.GeneratedProtocolMessageType('DeleteTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLERESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DeleteTableResponse)
  })
_sym_db.RegisterMessage(DeleteTableResponse)

LoadDataRequest = _reflection.GeneratedProtocolMessageType('LoadDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATAREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.LoadDataRequest)
  })
_sym_db.RegisterMessage(LoadDataRequest)

LoadDataResponse = _reflection.GeneratedProtocolMessageType('LoadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATARESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.table_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.LoadDataResponse)
  })
_sym_db.RegisterMessage(LoadDataResponse)

_TABLESERVICE = DESCRIPTOR.services_by_name['TableService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\021TableServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _TABLE.fields_by_name['table_id']._options = None
  _TABLE.fields_by_name['table_id']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['table_name']._options = None
  _TABLE.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['time_column_name']._options = None
  _TABLE.fields_by_name['time_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['entity_key_column_name']._options = None
  _TABLE.fields_by_name['entity_key_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['subsort_column_name']._options = None
  _TABLE.fields_by_name['subsort_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['create_time']._options = None
  _TABLE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['update_time']._options = None
  _TABLE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['version']._options = None
  _TABLE.fields_by_name['version']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['schema']._options = None
  _TABLE.fields_by_name['schema']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['file_count']._options = None
  _TABLE.fields_by_name['file_count']._serialized_options = b'\340A\003'
  _LISTTABLESREQUEST.fields_by_name['page_size']._options = None
  _LISTTABLESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETTABLEREQUEST.fields_by_name['table_name']._options = None
  _GETTABLEREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATETABLEREQUEST.fields_by_name['table']._options = None
  _CREATETABLEREQUEST.fields_by_name['table']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETETABLEREQUEST.fields_by_name['table_name']._options = None
  _DELETETABLEREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _LOADDATAREQUEST.oneofs_by_name['source_data']._options = None
  _LOADDATAREQUEST.oneofs_by_name['source_data']._serialized_options = b'\370B\001'
  _LOADDATAREQUEST.fields_by_name['table_name']._options = None
  _LOADDATAREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLESERVICE.methods_by_name['ListTables']._options = None
  _TABLESERVICE.methods_by_name['ListTables']._serialized_options = b'\202\323\344\223\002\021\022\017/v1alpha/tables'
  _TABLESERVICE.methods_by_name['GetTable']._options = None
  _TABLESERVICE.methods_by_name['GetTable']._serialized_options = b'\202\323\344\223\002 \022\036/v1alpha/tables/{table_name=*}'
  _TABLESERVICE.methods_by_name['CreateTable']._options = None
  _TABLESERVICE.methods_by_name['CreateTable']._serialized_options = b'\202\323\344\223\002\030:\005table\"\017/v1alpha/tables'
  _TABLESERVICE.methods_by_name['DeleteTable']._options = None
  _TABLESERVICE.methods_by_name['DeleteTable']._serialized_options = b'\202\323\344\223\002 *\036/v1alpha/tables/{table_name=*}'
  _TABLESERVICE.methods_by_name['LoadData']._options = None
  _TABLESERVICE.methods_by_name['LoadData']._serialized_options = b'\202\323\344\223\002\036:\001*\"\031/v1alpha/tables/load_data'
  _TABLE._serialized_start=302
  _TABLE._serialized_end=1070
  _TABLE_TABLESOURCE._serialized_start=956
  _TABLE_TABLESOURCE._serialized_end=1053
  _TABLE_KASKADASOURCE._serialized_start=1055
  _TABLE_KASKADASOURCE._serialized_end=1070
  _LISTTABLESREQUEST._serialized_start=1072
  _LISTTABLESREQUEST._serialized_end=1187
  _LISTTABLESRESPONSE._serialized_start=1190
  _LISTTABLESRESPONSE._serialized_end=1388
  _GETTABLEREQUEST._serialized_start=1390
  _GETTABLEREQUEST._serialized_end=1447
  _GETTABLERESPONSE._serialized_start=1450
  _GETTABLERESPONSE._serialized_end=1604
  _CREATETABLEREQUEST._serialized_start=1606
  _CREATETABLEREQUEST._serialized_end=1690
  _CREATETABLERESPONSE._serialized_start=1693
  _CREATETABLERESPONSE._serialized_end=1850
  _DELETETABLEREQUEST._serialized_start=1852
  _DELETETABLEREQUEST._serialized_end=1934
  _DELETETABLERESPONSE._serialized_start=1937
  _DELETETABLERESPONSE._serialized_end=2076
  _LOADDATAREQUEST._serialized_start=2079
  _LOADDATAREQUEST._serialized_end=2225
  _LOADDATARESPONSE._serialized_start=2228
  _LOADDATARESPONSE._serialized_end=2364
  _TABLESERVICE._serialized_start=2367
  _TABLESERVICE._serialized_end=3069
# @@protoc_insertion_point(module_scope)
