# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"kaskada/kaskada/v1alpha/plan.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\"\xba\x02\n\x0b\x43omputePlan\x12Z\n\x13per_entity_behavior\x18\x01 \x01(\x0e\x32*.kaskada.kaskada.v1alpha.PerEntityBehaviorR\x11perEntityBehavior\x12\x46\n\noperations\x18\x02 \x03(\x0b\x32&.kaskada.kaskada.v1alpha.OperationPlanR\noperations\x12)\n\x10primary_grouping\x18\x03 \x01(\tR\x0fprimaryGrouping\x12\\\n\x19primary_grouping_key_type\x18\x04 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.DataTypeR\x16primaryGroupingKeyType\"\xc6\x12\n\rOperationPlan\x12I\n\x0b\x65xpressions\x18\x01 \x03(\x0b\x32\'.kaskada.kaskada.v1alpha.ExpressionPlanR\x0b\x65xpressions\x12J\n\x04scan\x18\x02 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.OperationPlan.ScanOperationH\x00R\x04scan\x12M\n\x05merge\x18\x03 \x01(\x0b\x32\x35.kaskada.kaskada.v1alpha.OperationPlan.MergeOperationH\x00R\x05merge\x12P\n\x06select\x18\x04 \x01(\x0b\x32\x36.kaskada.kaskada.v1alpha.OperationPlan.SelectOperationH\x00R\x06select\x12J\n\x04tick\x18\x05 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.OperationPlan.TickOperationH\x00R\x04tick\x12T\n\x08with_key\x18\x06 \x01(\x0b\x32\x37.kaskada.kaskada.v1alpha.OperationPlan.WithKeyOperationH\x00R\x07withKey\x12\x66\n\x0elookup_request\x18\x07 \x01(\x0b\x32=.kaskada.kaskada.v1alpha.OperationPlan.LookupRequestOperationH\x00R\rlookupRequest\x12i\n\x0flookup_response\x18\x08 \x01(\x0b\x32>.kaskada.kaskada.v1alpha.OperationPlan.LookupResponseOperationH\x00R\x0elookupResponse\x12T\n\x08shift_to\x18\t \x01(\x0b\x32\x37.kaskada.kaskada.v1alpha.OperationPlan.ShiftToOperationH\x00R\x07shiftTo\x12]\n\x0bshift_until\x18\n \x01(\x0b\x32:.kaskada.kaskada.v1alpha.OperationPlan.ShiftUntilOperationH\x00R\nshiftUntil\x1a\xc5\x01\n\rScanOperation\x12\x38\n\x08table_id\x18\x01 \x01(\x0b\x32\x1d.kaskada.kaskada.v1alpha.UuidR\x07tableId\x12\x37\n\x06schema\x18\x02 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaR\x06schema\x12\x41\n\nslice_plan\x18\x03 \x01(\x0b\x32\".kaskada.kaskada.v1alpha.SlicePlanR\tslicePlan\x1a:\n\x0eMergeOperation\x12\x12\n\x04left\x18\x01 \x01(\rR\x04left\x12\x14\n\x05right\x18\x02 \x01(\rR\x05right\x1aq\n\x0fSelectOperation\x12\x14\n\x05input\x18\x01 \x01(\rR\x05input\x12H\n\tcondition\x18\x02 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.OperationInputRefR\tcondition\x1a\x89\x01\n\x10WithKeyOperation\x12\x14\n\x05input\x18\x01 \x01(\rR\x05input\x12\x43\n\x07new_key\x18\x02 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.OperationInputRefR\x06newKey\x12\x1a\n\x08grouping\x18\x03 \x01(\tR\x08grouping\x1a\xd4\x02\n\rTickOperation\x12]\n\x08\x62\x65havior\x18\x01 \x01(\x0e\x32\x41.kaskada.kaskada.v1alpha.OperationPlan.TickOperation.TickBehaviorR\x08\x62\x65havior\x12\x14\n\x05input\x18\x02 \x01(\rR\x05input\"\xcd\x01\n\x0cTickBehavior\x12\x1d\n\x19TICK_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1a\n\x16TICK_BEHAVIOR_FINISHED\x10\x01\x12\x18\n\x14TICK_BEHAVIOR_HOURLY\x10\x02\x12\x17\n\x13TICK_BEHAVIOR_DAILY\x10\x03\x12\x19\n\x15TICK_BEHAVIOR_MONTHLY\x10\x04\x12\x18\n\x14TICK_BEHAVIOR_YEARLY\x10\x05\x12\x1a\n\x16TICK_BEHAVIOR_MINUTELY\x10\x06\x1a\x9b\x01\n\x16LookupRequestOperation\x12+\n\x11primary_operation\x18\x01 \x01(\rR\x10primaryOperation\x12T\n\x10\x66oreign_key_hash\x18\x02 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.OperationInputRefR\x0e\x66oreignKeyHash\x1a\xa2\x01\n\x17LookupResponseOperation\x12+\n\x11\x66oreign_operation\x18\x01 \x01(\rR\x10\x66oreignOperation\x12Z\n\x13requesting_key_hash\x18\x02 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.OperationInputRefR\x11requestingKeyHash\x1a\xb2\x01\n\x10ShiftToOperation\x12\x14\n\x05input\x18\x01 \x01(\rR\x05input\x12H\n\x08\x63omputed\x18\x02 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.OperationInputRefH\x00R\x08\x63omputed\x12\x36\n\x07literal\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x07literalB\x06\n\x04time\x1au\n\x13ShiftUntilOperation\x12\x14\n\x05input\x18\x01 \x01(\rR\x05input\x12H\n\tcondition\x18\x02 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.OperationInputRefR\tconditionB\n\n\x08operator\"\x86\x03\n\x0e\x45xpressionPlan\x12\x1c\n\targuments\x18\x01 \x03(\rR\targuments\x12\x42\n\x0bresult_type\x18\x02 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.DataTypeR\nresultType\x12\x16\n\x06output\x18\x03 \x01(\x08R\x06output\x12\"\n\x0binstruction\x18\x04 \x01(\tH\x00R\x0binstruction\x12\x42\n\x05input\x18\x05 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.OperationInputRefH\x00R\x05input\x12<\n\x07literal\x18\x06 \x01(\x0b\x32 .kaskada.kaskada.v1alpha.LiteralH\x00R\x07literal\x12H\n\nlate_bound\x18\x07 \x01(\x0e\x32\'.kaskada.kaskada.v1alpha.LateBoundValueH\x00R\tlateBoundB\n\n\x08operator\"\xb5\n\n\x07Literal\x12\x14\n\x04\x62ool\x18\x08 \x01(\x08H\x00R\x04\x62ool\x12\x14\n\x04int8\x18\t \x01(\x05H\x00R\x04int8\x12\x16\n\x05int16\x18\n \x01(\x05H\x00R\x05int16\x12\x16\n\x05int32\x18\x0b \x01(\x05H\x00R\x05int32\x12\x16\n\x05int64\x18\x0c \x01(\x03H\x00R\x05int64\x12\x16\n\x05uint8\x18\r \x01(\rH\x00R\x05uint8\x12\x18\n\x06uint16\x18\x0e \x01(\rH\x00R\x06uint16\x12\x18\n\x06uint32\x18\x0f \x01(\rH\x00R\x06uint32\x12\x18\n\x06uint64\x18\x10 \x01(\x04H\x00R\x06uint64\x12\x1a\n\x07\x66loat32\x18\x11 \x01(\x02H\x00R\x07\x66loat32\x12\x1a\n\x07\x66loat64\x18\x12 \x01(\x01H\x00R\x07\x66loat64\x12O\n\ttimestamp\x18\x13 \x01(\x0b\x32/.kaskada.kaskada.v1alpha.Literal.TimestampValueH\x00R\ttimestamp\x12\x18\n\x06\x64\x61te32\x18\x14 \x01(\x05H\x00R\x06\x64\x61te32\x12\x18\n\x06\x64\x61te64\x18\x15 \x01(\x03H\x00R\x06\x64\x61te64\x12\x46\n\x06time32\x18\x16 \x01(\x0b\x32,.kaskada.kaskada.v1alpha.Literal.Time32ValueH\x00R\x06time32\x12\x46\n\x06time64\x18\x17 \x01(\x0b\x32,.kaskada.kaskada.v1alpha.Literal.Time64ValueH\x00R\x06time64\x12L\n\x08\x64uration\x18\x18 \x01(\x0b\x32..kaskada.kaskada.v1alpha.Literal.DurationValueH\x00R\x08\x64uration\x12\x63\n\x11interval_day_time\x18\x19 \x01(\x0b\x32\x35.kaskada.kaskada.v1alpha.Literal.IntervalDayTimeValueH\x00R\x0fintervalDayTime\x12)\n\x0finterval_months\x18\x1a \x01(\x05H\x00R\x0eintervalMonths\x12\x14\n\x04utf8\x18\x1b \x01(\tH\x00R\x04utf8\x12\x46\n\x06record\x18\x1c \x01(\x0b\x32,.kaskada.kaskada.v1alpha.Literal.RecordValueH\x00R\x06record\x1a\x85\x01\n\x0eTimestampValue\x12\x31\n\x05value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x05value\x12\x12\n\x04unit\x18\x02 \x01(\tR\x04unit\x12,\n\x02tz\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x02tz\x1a\x37\n\x0bTime32Value\x12\x14\n\x05value\x18\x01 \x01(\x05R\x05value\x12\x12\n\x04unit\x18\x02 \x01(\tR\x04unit\x1a\x37\n\x0bTime64Value\x12\x14\n\x05value\x18\x01 \x01(\x03R\x05value\x12\x12\n\x04unit\x18\x02 \x01(\tR\x04unit\x1a\x39\n\rDurationValue\x12\x14\n\x05value\x18\x01 \x01(\x03R\x05value\x12\x12\n\x04unit\x18\x02 \x01(\tR\x04unit\x1a>\n\x14IntervalDayTimeValue\x12\x14\n\x05start\x18\x01 \x01(\x05R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05R\x03\x65nd\x1aG\n\x0bRecordValue\x12\x38\n\x06values\x18\x01 \x03(\x0b\x32 .kaskada.kaskada.v1alpha.LiteralR\x06valuesB\t\n\x07literal\"\x94\x05\n\x11OperationInputRef\x12/\n\x13producing_operation\x18\x01 \x01(\rR\x12producingOperation\x12U\n\nkey_column\x18\x02 \x01(\x0e\x32\x34.kaskada.kaskada.v1alpha.OperationInputRef.KeyColumnH\x00R\tkeyColumn\x12\x31\n\x13producer_expression\x18\x03 \x01(\rH\x00R\x12producerExpression\x12\x39\n\x0bscan_record\x18\x04 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\nscanRecord\x12,\n\x04tick\x18\x07 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x04tick\x12!\n\x0cinput_column\x18\x05 \x01(\rR\x0binputColumn\x12^\n\rinterpolation\x18\x06 \x01(\x0e\x32\x38.kaskada.kaskada.v1alpha.OperationInputRef.InterpolationR\rinterpolation\"m\n\tKeyColumn\x12\x1a\n\x16KEY_COLUMN_UNSPECIFIED\x10\x00\x12\x13\n\x0fKEY_COLUMN_TIME\x10\x01\x12\x16\n\x12KEY_COLUMN_SUBSORT\x10\x02\x12\x17\n\x13KEY_COLUMN_KEY_HASH\x10\x03\"_\n\rInterpolation\x12\x1d\n\x19INTERPOLATION_UNSPECIFIED\x10\x00\x12\x16\n\x12INTERPOLATION_NULL\x10\x01\x12\x17\n\x13INTERPOLATION_AS_OF\x10\x02\x42\x08\n\x06\x63olumn*\x7f\n\x0eLateBoundValue\x12 \n\x1cLATE_BOUND_VALUE_UNSPECIFIED\x10\x00\x12\'\n#LATE_BOUND_VALUE_CHANGED_SINCE_TIME\x10\x01\x12\"\n\x1eLATE_BOUND_VALUE_FINAL_AT_TIME\x10\x02\x42\xf9\x01\n\x1b\x63om.kaskada.kaskada.v1alphaB\tPlanProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')

_LATEBOUNDVALUE = DESCRIPTOR.enum_types_by_name['LateBoundValue']
LateBoundValue = enum_type_wrapper.EnumTypeWrapper(_LATEBOUNDVALUE)
LATE_BOUND_VALUE_UNSPECIFIED = 0
LATE_BOUND_VALUE_CHANGED_SINCE_TIME = 1
LATE_BOUND_VALUE_FINAL_AT_TIME = 2


_COMPUTEPLAN = DESCRIPTOR.message_types_by_name['ComputePlan']
_OPERATIONPLAN = DESCRIPTOR.message_types_by_name['OperationPlan']
_OPERATIONPLAN_SCANOPERATION = _OPERATIONPLAN.nested_types_by_name['ScanOperation']
_OPERATIONPLAN_MERGEOPERATION = _OPERATIONPLAN.nested_types_by_name['MergeOperation']
_OPERATIONPLAN_SELECTOPERATION = _OPERATIONPLAN.nested_types_by_name['SelectOperation']
_OPERATIONPLAN_WITHKEYOPERATION = _OPERATIONPLAN.nested_types_by_name['WithKeyOperation']
_OPERATIONPLAN_TICKOPERATION = _OPERATIONPLAN.nested_types_by_name['TickOperation']
_OPERATIONPLAN_LOOKUPREQUESTOPERATION = _OPERATIONPLAN.nested_types_by_name['LookupRequestOperation']
_OPERATIONPLAN_LOOKUPRESPONSEOPERATION = _OPERATIONPLAN.nested_types_by_name['LookupResponseOperation']
_OPERATIONPLAN_SHIFTTOOPERATION = _OPERATIONPLAN.nested_types_by_name['ShiftToOperation']
_OPERATIONPLAN_SHIFTUNTILOPERATION = _OPERATIONPLAN.nested_types_by_name['ShiftUntilOperation']
_EXPRESSIONPLAN = DESCRIPTOR.message_types_by_name['ExpressionPlan']
_LITERAL = DESCRIPTOR.message_types_by_name['Literal']
_LITERAL_TIMESTAMPVALUE = _LITERAL.nested_types_by_name['TimestampValue']
_LITERAL_TIME32VALUE = _LITERAL.nested_types_by_name['Time32Value']
_LITERAL_TIME64VALUE = _LITERAL.nested_types_by_name['Time64Value']
_LITERAL_DURATIONVALUE = _LITERAL.nested_types_by_name['DurationValue']
_LITERAL_INTERVALDAYTIMEVALUE = _LITERAL.nested_types_by_name['IntervalDayTimeValue']
_LITERAL_RECORDVALUE = _LITERAL.nested_types_by_name['RecordValue']
_OPERATIONINPUTREF = DESCRIPTOR.message_types_by_name['OperationInputRef']
_OPERATIONPLAN_TICKOPERATION_TICKBEHAVIOR = _OPERATIONPLAN_TICKOPERATION.enum_types_by_name['TickBehavior']
_OPERATIONINPUTREF_KEYCOLUMN = _OPERATIONINPUTREF.enum_types_by_name['KeyColumn']
_OPERATIONINPUTREF_INTERPOLATION = _OPERATIONINPUTREF.enum_types_by_name['Interpolation']
ComputePlan = _reflection.GeneratedProtocolMessageType('ComputePlan', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTEPLAN,
  '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ComputePlan)
  })
_sym_db.RegisterMessage(ComputePlan)

OperationPlan = _reflection.GeneratedProtocolMessageType('OperationPlan', (_message.Message,), {

  'ScanOperation' : _reflection.GeneratedProtocolMessageType('ScanOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_SCANOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.ScanOperation)
    })
  ,

  'MergeOperation' : _reflection.GeneratedProtocolMessageType('MergeOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_MERGEOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.MergeOperation)
    })
  ,

  'SelectOperation' : _reflection.GeneratedProtocolMessageType('SelectOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_SELECTOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.SelectOperation)
    })
  ,

  'WithKeyOperation' : _reflection.GeneratedProtocolMessageType('WithKeyOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_WITHKEYOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.WithKeyOperation)
    })
  ,

  'TickOperation' : _reflection.GeneratedProtocolMessageType('TickOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_TICKOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.TickOperation)
    })
  ,

  'LookupRequestOperation' : _reflection.GeneratedProtocolMessageType('LookupRequestOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_LOOKUPREQUESTOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.LookupRequestOperation)
    })
  ,

  'LookupResponseOperation' : _reflection.GeneratedProtocolMessageType('LookupResponseOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_LOOKUPRESPONSEOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.LookupResponseOperation)
    })
  ,

  'ShiftToOperation' : _reflection.GeneratedProtocolMessageType('ShiftToOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_SHIFTTOOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.ShiftToOperation)
    })
  ,

  'ShiftUntilOperation' : _reflection.GeneratedProtocolMessageType('ShiftUntilOperation', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONPLAN_SHIFTUNTILOPERATION,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan.ShiftUntilOperation)
    })
  ,
  'DESCRIPTOR' : _OPERATIONPLAN,
  '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationPlan)
  })
_sym_db.RegisterMessage(OperationPlan)
_sym_db.RegisterMessage(OperationPlan.ScanOperation)
_sym_db.RegisterMessage(OperationPlan.MergeOperation)
_sym_db.RegisterMessage(OperationPlan.SelectOperation)
_sym_db.RegisterMessage(OperationPlan.WithKeyOperation)
_sym_db.RegisterMessage(OperationPlan.TickOperation)
_sym_db.RegisterMessage(OperationPlan.LookupRequestOperation)
_sym_db.RegisterMessage(OperationPlan.LookupResponseOperation)
_sym_db.RegisterMessage(OperationPlan.ShiftToOperation)
_sym_db.RegisterMessage(OperationPlan.ShiftUntilOperation)

ExpressionPlan = _reflection.GeneratedProtocolMessageType('ExpressionPlan', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONPLAN,
  '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExpressionPlan)
  })
_sym_db.RegisterMessage(ExpressionPlan)

Literal = _reflection.GeneratedProtocolMessageType('Literal', (_message.Message,), {

  'TimestampValue' : _reflection.GeneratedProtocolMessageType('TimestampValue', (_message.Message,), {
    'DESCRIPTOR' : _LITERAL_TIMESTAMPVALUE,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Literal.TimestampValue)
    })
  ,

  'Time32Value' : _reflection.GeneratedProtocolMessageType('Time32Value', (_message.Message,), {
    'DESCRIPTOR' : _LITERAL_TIME32VALUE,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Literal.Time32Value)
    })
  ,

  'Time64Value' : _reflection.GeneratedProtocolMessageType('Time64Value', (_message.Message,), {
    'DESCRIPTOR' : _LITERAL_TIME64VALUE,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Literal.Time64Value)
    })
  ,

  'DurationValue' : _reflection.GeneratedProtocolMessageType('DurationValue', (_message.Message,), {
    'DESCRIPTOR' : _LITERAL_DURATIONVALUE,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Literal.DurationValue)
    })
  ,

  'IntervalDayTimeValue' : _reflection.GeneratedProtocolMessageType('IntervalDayTimeValue', (_message.Message,), {
    'DESCRIPTOR' : _LITERAL_INTERVALDAYTIMEVALUE,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Literal.IntervalDayTimeValue)
    })
  ,

  'RecordValue' : _reflection.GeneratedProtocolMessageType('RecordValue', (_message.Message,), {
    'DESCRIPTOR' : _LITERAL_RECORDVALUE,
    '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Literal.RecordValue)
    })
  ,
  'DESCRIPTOR' : _LITERAL,
  '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Literal)
  })
_sym_db.RegisterMessage(Literal)
_sym_db.RegisterMessage(Literal.TimestampValue)
_sym_db.RegisterMessage(Literal.Time32Value)
_sym_db.RegisterMessage(Literal.Time64Value)
_sym_db.RegisterMessage(Literal.DurationValue)
_sym_db.RegisterMessage(Literal.IntervalDayTimeValue)
_sym_db.RegisterMessage(Literal.RecordValue)

OperationInputRef = _reflection.GeneratedProtocolMessageType('OperationInputRef', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONINPUTREF,
  '__module__' : 'kaskada.kaskada.v1alpha.plan_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OperationInputRef)
  })
_sym_db.RegisterMessage(OperationInputRef)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\tPlanProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _LATEBOUNDVALUE._serialized_start=5319
  _LATEBOUNDVALUE._serialized_end=5446
  _COMPUTEPLAN._serialized_start=234
  _COMPUTEPLAN._serialized_end=548
  _OPERATIONPLAN._serialized_start=551
  _OPERATIONPLAN._serialized_end=2925
  _OPERATIONPLAN_SCANOPERATION._serialized_start=1435
  _OPERATIONPLAN_SCANOPERATION._serialized_end=1632
  _OPERATIONPLAN_MERGEOPERATION._serialized_start=1634
  _OPERATIONPLAN_MERGEOPERATION._serialized_end=1692
  _OPERATIONPLAN_SELECTOPERATION._serialized_start=1694
  _OPERATIONPLAN_SELECTOPERATION._serialized_end=1807
  _OPERATIONPLAN_WITHKEYOPERATION._serialized_start=1810
  _OPERATIONPLAN_WITHKEYOPERATION._serialized_end=1947
  _OPERATIONPLAN_TICKOPERATION._serialized_start=1950
  _OPERATIONPLAN_TICKOPERATION._serialized_end=2290
  _OPERATIONPLAN_TICKOPERATION_TICKBEHAVIOR._serialized_start=2085
  _OPERATIONPLAN_TICKOPERATION_TICKBEHAVIOR._serialized_end=2290
  _OPERATIONPLAN_LOOKUPREQUESTOPERATION._serialized_start=2293
  _OPERATIONPLAN_LOOKUPREQUESTOPERATION._serialized_end=2448
  _OPERATIONPLAN_LOOKUPRESPONSEOPERATION._serialized_start=2451
  _OPERATIONPLAN_LOOKUPRESPONSEOPERATION._serialized_end=2613
  _OPERATIONPLAN_SHIFTTOOPERATION._serialized_start=2616
  _OPERATIONPLAN_SHIFTTOOPERATION._serialized_end=2794
  _OPERATIONPLAN_SHIFTUNTILOPERATION._serialized_start=2796
  _OPERATIONPLAN_SHIFTUNTILOPERATION._serialized_end=2913
  _EXPRESSIONPLAN._serialized_start=2928
  _EXPRESSIONPLAN._serialized_end=3318
  _LITERAL._serialized_start=3321
  _LITERAL._serialized_end=4654
  _LITERAL_TIMESTAMPVALUE._serialized_start=4200
  _LITERAL_TIMESTAMPVALUE._serialized_end=4333
  _LITERAL_TIME32VALUE._serialized_start=4335
  _LITERAL_TIME32VALUE._serialized_end=4390
  _LITERAL_TIME64VALUE._serialized_start=4392
  _LITERAL_TIME64VALUE._serialized_end=4447
  _LITERAL_DURATIONVALUE._serialized_start=4449
  _LITERAL_DURATIONVALUE._serialized_end=4506
  _LITERAL_INTERVALDAYTIMEVALUE._serialized_start=4508
  _LITERAL_INTERVALDAYTIMEVALUE._serialized_end=4570
  _LITERAL_RECORDVALUE._serialized_start=4572
  _LITERAL_RECORDVALUE._serialized_end=4643
  _OPERATIONINPUTREF._serialized_start=4657
  _OPERATIONINPUTREF._serialized_end=5317
  _OPERATIONINPUTREF_KEYCOLUMN._serialized_start=5101
  _OPERATIONINPUTREF_KEYCOLUMN._serialized_end=5210
  _OPERATIONINPUTREF_INTERPOLATION._serialized_start=5212
  _OPERATIONINPUTREF_INTERPOLATION._serialized_end=5307
# @@protoc_insertion_point(module_scope)
