# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/materialization_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import destinations_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_destinations__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5kaskada/kaskada/v1alpha/materialization_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a*kaskada/kaskada/v1alpha/destinations.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\x1a\x17validate/validate.proto\"P\n\x08WithView\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\'\n\nexpression\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\"D\n\tWithViews\x12\x37\n\x05views\x18\x01 \x03(\x0b\x32!.kaskada.kaskada.v1alpha.WithViewR\x05views\"\xea\x05\n\x0fMaterialization\x12\x32\n\x12materialization_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x11materializationId\x12:\n\x14materialization_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x14\n\x05query\x18\x04 \x01(\tR\x05query\x12@\n\nwith_views\x18\x05 \x03(\x0b\x32!.kaskada.kaskada.v1alpha.WithViewR\twithViews\x12V\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.Materialization.DestinationR\x0b\x64\x65stination\x12<\n\x06schema\x18\x07 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\x12;\n\x05slice\x18\x08 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x05slice\x12\x42\n\x08\x61nalysis\x18\t \x01(\x0b\x32!.kaskada.kaskada.v1alpha.AnalysisB\x03\xe0\x41\x03R\x08\x61nalysis\x1a\xb5\x01\n\x0b\x44\x65stination\x12\x41\n\x05redis\x18\x01 \x01(\x0b\x32).kaskada.kaskada.v1alpha.RedisDestinationH\x00R\x05redis\x12T\n\x0cobject_store\x18\x02 \x01(\x0b\x32/.kaskada.kaskada.v1alpha.ObjectStoreDestinationH\x00R\x0bobjectStoreB\r\n\x0b\x64\x65stination\"}\n\x1bListMaterializationsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xee\x01\n\x1cListMaterializationsResponse\x12T\n\x10materializations\x18\x01 \x03(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x10materializations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12P\n\x0frequest_details\x18\x03 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"W\n\x19GetMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"\xc2\x01\n\x1aGetMaterializationResponse\x12R\n\x0fmaterialization\x18\x01 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x0fmaterialization\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"\x8b\x01\n\x1c\x43reateMaterializationRequest\x12R\n\x0fmaterialization\x18\x01 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x0fmaterialization\x12\x17\n\x07\x64ry_run\x18\x02 \x01(\x08R\x06\x64ryRun\"\x84\x02\n\x1d\x43reateMaterializationResponse\x12R\n\x0fmaterialization\x18\x01 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x0fmaterialization\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\x12=\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.AnalysisR\x08\x61nalysis\"Z\n\x1c\x44\x65leteMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"q\n\x1d\x44\x65leteMaterializationResponse\x12P\n\x0frequest_details\x18\x01 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails2\xff\x05\n\x16MaterializationService\x12\xa6\x01\n\x14ListMaterializations\x12\x34.kaskada.kaskada.v1alpha.ListMaterializationsRequest\x1a\x35.kaskada.kaskada.v1alpha.ListMaterializationsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1alpha/materializations\x12\xb9\x01\n\x12GetMaterialization\x12\x32.kaskada.kaskada.v1alpha.GetMaterializationRequest\x1a\x33.kaskada.kaskada.v1alpha.GetMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/materializations/{materialization_name=*}\x12\xba\x01\n\x15\x43reateMaterialization\x12\x35.kaskada.kaskada.v1alpha.CreateMaterializationRequest\x1a\x36.kaskada.kaskada.v1alpha.CreateMaterializationResponse\"2\x82\xd3\xe4\x93\x02,:\x0fmaterialization\"\x19/v1alpha/materializations\x12\xc2\x01\n\x15\x44\x65leteMaterialization\x12\x35.kaskada.kaskada.v1alpha.DeleteMaterializationRequest\x1a\x36.kaskada.kaskada.v1alpha.DeleteMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34*2/v1alpha/materializations/{materialization_name=*}B\x8b\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x1bMaterializationServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_WITHVIEW = DESCRIPTOR.message_types_by_name['WithView']
_WITHVIEWS = DESCRIPTOR.message_types_by_name['WithViews']
_MATERIALIZATION = DESCRIPTOR.message_types_by_name['Materialization']
_MATERIALIZATION_DESTINATION = _MATERIALIZATION.nested_types_by_name['Destination']
_LISTMATERIALIZATIONSREQUEST = DESCRIPTOR.message_types_by_name['ListMaterializationsRequest']
_LISTMATERIALIZATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListMaterializationsResponse']
_GETMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['GetMaterializationRequest']
_GETMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetMaterializationResponse']
_CREATEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateMaterializationRequest']
_CREATEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateMaterializationResponse']
_DELETEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteMaterializationRequest']
_DELETEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteMaterializationResponse']
WithView = _reflection.GeneratedProtocolMessageType('WithView', (_message.Message,), {
  'DESCRIPTOR' : _WITHVIEW,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.WithView)
  })
_sym_db.RegisterMessage(WithView)

WithViews = _reflection.GeneratedProtocolMessageType('WithViews', (_message.Message,), {
  'DESCRIPTOR' : _WITHVIEWS,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.WithViews)
  })
_sym_db.RegisterMessage(WithViews)

Materialization = _reflection.GeneratedProtocolMessageType('Materialization', (_message.Message,), {

  'Destination' : _reflection.GeneratedProtocolMessageType('Destination', (_message.Message,), {
    'DESCRIPTOR' : _MATERIALIZATION_DESTINATION,
    '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Materialization.Destination)
    })
  ,
  'DESCRIPTOR' : _MATERIALIZATION,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Materialization)
  })
_sym_db.RegisterMessage(Materialization)
_sym_db.RegisterMessage(Materialization.Destination)

ListMaterializationsRequest = _reflection.GeneratedProtocolMessageType('ListMaterializationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListMaterializationsRequest)
  })
_sym_db.RegisterMessage(ListMaterializationsRequest)

ListMaterializationsResponse = _reflection.GeneratedProtocolMessageType('ListMaterializationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListMaterializationsResponse)
  })
_sym_db.RegisterMessage(ListMaterializationsResponse)

GetMaterializationRequest = _reflection.GeneratedProtocolMessageType('GetMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetMaterializationRequest)
  })
_sym_db.RegisterMessage(GetMaterializationRequest)

GetMaterializationResponse = _reflection.GeneratedProtocolMessageType('GetMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetMaterializationResponse)
  })
_sym_db.RegisterMessage(GetMaterializationResponse)

CreateMaterializationRequest = _reflection.GeneratedProtocolMessageType('CreateMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateMaterializationRequest)
  })
_sym_db.RegisterMessage(CreateMaterializationRequest)

CreateMaterializationResponse = _reflection.GeneratedProtocolMessageType('CreateMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateMaterializationResponse)
  })
_sym_db.RegisterMessage(CreateMaterializationResponse)

DeleteMaterializationRequest = _reflection.GeneratedProtocolMessageType('DeleteMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DeleteMaterializationRequest)
  })
_sym_db.RegisterMessage(DeleteMaterializationRequest)

DeleteMaterializationResponse = _reflection.GeneratedProtocolMessageType('DeleteMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DeleteMaterializationResponse)
  })
_sym_db.RegisterMessage(DeleteMaterializationResponse)

_MATERIALIZATIONSERVICE = DESCRIPTOR.services_by_name['MaterializationService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\033MaterializationServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _WITHVIEW.fields_by_name['name']._options = None
  _WITHVIEW.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WITHVIEW.fields_by_name['expression']._options = None
  _WITHVIEW.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION.fields_by_name['materialization_id']._options = None
  _MATERIALIZATION.fields_by_name['materialization_id']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['materialization_name']._options = None
  _MATERIALIZATION.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION.fields_by_name['create_time']._options = None
  _MATERIALIZATION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['schema']._options = None
  _MATERIALIZATION.fields_by_name['schema']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['analysis']._options = None
  _MATERIALIZATION.fields_by_name['analysis']._serialized_options = b'\340A\003'
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._serialized_options = b'\202\323\344\223\002\033\022\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._serialized_options = b'\202\323\344\223\0024\0222/v1alpha/materializations/{materialization_name=*}'
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._serialized_options = b'\202\323\344\223\002,:\017materialization\"\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._serialized_options = b'\202\323\344\223\0024*2/v1alpha/materializations/{materialization_name=*}'
  _WITHVIEW._serialized_start=323
  _WITHVIEW._serialized_end=403
  _WITHVIEWS._serialized_start=405
  _WITHVIEWS._serialized_end=473
  _MATERIALIZATION._serialized_start=476
  _MATERIALIZATION._serialized_end=1222
  _MATERIALIZATION_DESTINATION._serialized_start=1041
  _MATERIALIZATION_DESTINATION._serialized_end=1222
  _LISTMATERIALIZATIONSREQUEST._serialized_start=1224
  _LISTMATERIALIZATIONSREQUEST._serialized_end=1349
  _LISTMATERIALIZATIONSRESPONSE._serialized_start=1352
  _LISTMATERIALIZATIONSRESPONSE._serialized_end=1590
  _GETMATERIALIZATIONREQUEST._serialized_start=1592
  _GETMATERIALIZATIONREQUEST._serialized_end=1679
  _GETMATERIALIZATIONRESPONSE._serialized_start=1682
  _GETMATERIALIZATIONRESPONSE._serialized_end=1876
  _CREATEMATERIALIZATIONREQUEST._serialized_start=1879
  _CREATEMATERIALIZATIONREQUEST._serialized_end=2018
  _CREATEMATERIALIZATIONRESPONSE._serialized_start=2021
  _CREATEMATERIALIZATIONRESPONSE._serialized_end=2281
  _DELETEMATERIALIZATIONREQUEST._serialized_start=2283
  _DELETEMATERIALIZATIONREQUEST._serialized_end=2373
  _DELETEMATERIALIZATIONRESPONSE._serialized_start=2375
  _DELETEMATERIALIZATIONRESPONSE._serialized_end=2488
  _MATERIALIZATIONSERVICE._serialized_start=2491
  _MATERIALIZATIONSERVICE._serialized_end=3258
# @@protoc_insertion_point(module_scope)
