# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.kaskada.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/kaskada/v1alpha/common.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a.kaskada/kaskada/v1alpha/fenl_diagnostics.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\"q\n\x08\x46ilePath\x12#\n\x0cparquet_path\x18\x01 \x01(\tH\x00R\x0bparquetPath\x12\x1b\n\x08\x63sv_path\x18\x02 \x01(\tH\x00R\x07\x63svPath\x12\x1b\n\x08\x63sv_data\x18\x03 \x01(\tH\x00R\x07\x63svDataB\x06\n\x04path\"]\n\tFileInput\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\x12\x10\n\x03uri\x18\x02 \x01(\tR\x03uri\"c\n\x0b\x46ileResults\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\x12\x14\n\x05paths\x18\x02 \x03(\tR\x05paths\"I\n\x07\x41sFiles\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\"\xf5\x01\n\x0bTableConfig\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04uuid\x18\x06 \x01(\tR\x04uuid\x12(\n\x10time_column_name\x18\x02 \x01(\tR\x0etimeColumnName\x12L\n\x13subsort_column_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11subsortColumnName\x12*\n\x11group_column_name\x18\x04 \x01(\tR\x0fgroupColumnName\x12\x1a\n\x08grouping\x18\x05 \x01(\tR\x08grouping\"g\n\rTableMetadata\x12\x37\n\x06schema\x18\x01 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaR\x06schema\x12\x1d\n\nfile_count\x18\x02 \x01(\x03R\tfileCount\"\xe6\x01\n\x0cPreparedFile\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12@\n\x0emin_event_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cminEventTime\x12@\n\x0emax_event_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cmaxEventTime\x12\x19\n\x08num_rows\x18\x04 \x01(\x03R\x07numRows\x12#\n\rmetadata_path\x18\x05 \x01(\tR\x0cmetadataPath\"\x88\x01\n\x14PreparedFileMetadata\x12\"\n\rraw_file_path\x18\x01 \x01(\tR\x0brawFilePath\x12L\n\x0eprepared_files\x18\x02 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.PreparedFileR\rpreparedFiles\"\xb5\x02\n\tSlicePlan\x12\x1d\n\ntable_name\x18\x01 \x01(\tR\ttableName\x12K\n\x07percent\x18\x02 \x01(\x0b\x32/.kaskada.kaskada.v1alpha.SlicePlan.PercentSliceH\x00R\x07percent\x12U\n\x0b\x65ntity_keys\x18\x03 \x01(\x0b\x32\x32.kaskada.kaskada.v1alpha.SlicePlan.EntityKeysSliceH\x00R\nentityKeys\x1a(\n\x0cPercentSlice\x12\x18\n\x07percent\x18\x01 \x01(\x01R\x07percent\x1a\x32\n\x0f\x45ntityKeysSlice\x12\x1f\n\x0b\x65ntity_keys\x18\x01 \x03(\tR\nentityKeysB\x07\n\x05slice\",\n\x04Uuid\x12\x12\n\x04high\x18\x01 \x01(\x04R\x04high\x12\x10\n\x03low\x18\x02 \x01(\x04R\x03low\"\x9f\x02\n\x0cSliceRequest\x12N\n\x07percent\x18\x01 \x01(\x0b\x32\x32.kaskada.kaskada.v1alpha.SliceRequest.PercentSliceH\x00R\x07percent\x12X\n\x0b\x65ntity_keys\x18\x02 \x01(\x0b\x32\x35.kaskada.kaskada.v1alpha.SliceRequest.EntityKeysSliceH\x00R\nentityKeys\x1a(\n\x0cPercentSlice\x12\x18\n\x07percent\x18\x01 \x01(\x01R\x07percent\x1a\x32\n\x0f\x45ntityKeysSlice\x12\x1f\n\x0b\x65ntity_keys\x18\x02 \x03(\tR\nentityKeysB\x07\n\x05slice\"\xc4\x01\n\x08\x41nalysis\x12#\n\rmissing_names\x18\x01 \x03(\tR\x0cmissingNames\x12S\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x1f\n\x0b\x63\x61n_execute\x18\x03 \x01(\x08R\ncanExecute\x12\x1d\n\nfree_names\x18\x04 \x03(\tR\tfreeNames\"/\n\x0eRequestDetails\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId*O\n\x08\x46ileType\x12\x19\n\x15\x46ILE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x46ILE_TYPE_PARQUET\x10\x01\x12\x11\n\rFILE_TYPE_CSV\x10\x02*\x9b\x01\n\x11PerEntityBehavior\x12#\n\x1fPER_ENTITY_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1b\n\x17PER_ENTITY_BEHAVIOR_ALL\x10\x01\x12\x1d\n\x19PER_ENTITY_BEHAVIOR_FINAL\x10\x02\x12%\n!PER_ENTITY_BEHAVIOR_FINAL_AT_TIME\x10\x03\x42\xfb\x01\n\x1b\x63om.kaskada.kaskada.v1alphaB\x0b\x43ommonProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')

_FILETYPE = DESCRIPTOR.enum_types_by_name['FileType']
FileType = enum_type_wrapper.EnumTypeWrapper(_FILETYPE)
_PERENTITYBEHAVIOR = DESCRIPTOR.enum_types_by_name['PerEntityBehavior']
PerEntityBehavior = enum_type_wrapper.EnumTypeWrapper(_PERENTITYBEHAVIOR)
FILE_TYPE_UNSPECIFIED = 0
FILE_TYPE_PARQUET = 1
FILE_TYPE_CSV = 2
PER_ENTITY_BEHAVIOR_UNSPECIFIED = 0
PER_ENTITY_BEHAVIOR_ALL = 1
PER_ENTITY_BEHAVIOR_FINAL = 2
PER_ENTITY_BEHAVIOR_FINAL_AT_TIME = 3


_FILEPATH = DESCRIPTOR.message_types_by_name['FilePath']
_FILEINPUT = DESCRIPTOR.message_types_by_name['FileInput']
_FILERESULTS = DESCRIPTOR.message_types_by_name['FileResults']
_ASFILES = DESCRIPTOR.message_types_by_name['AsFiles']
_TABLECONFIG = DESCRIPTOR.message_types_by_name['TableConfig']
_TABLEMETADATA = DESCRIPTOR.message_types_by_name['TableMetadata']
_PREPAREDFILE = DESCRIPTOR.message_types_by_name['PreparedFile']
_PREPAREDFILEMETADATA = DESCRIPTOR.message_types_by_name['PreparedFileMetadata']
_SLICEPLAN = DESCRIPTOR.message_types_by_name['SlicePlan']
_SLICEPLAN_PERCENTSLICE = _SLICEPLAN.nested_types_by_name['PercentSlice']
_SLICEPLAN_ENTITYKEYSSLICE = _SLICEPLAN.nested_types_by_name['EntityKeysSlice']
_UUID = DESCRIPTOR.message_types_by_name['Uuid']
_SLICEREQUEST = DESCRIPTOR.message_types_by_name['SliceRequest']
_SLICEREQUEST_PERCENTSLICE = _SLICEREQUEST.nested_types_by_name['PercentSlice']
_SLICEREQUEST_ENTITYKEYSSLICE = _SLICEREQUEST.nested_types_by_name['EntityKeysSlice']
_ANALYSIS = DESCRIPTOR.message_types_by_name['Analysis']
_REQUESTDETAILS = DESCRIPTOR.message_types_by_name['RequestDetails']
FilePath = _reflection.GeneratedProtocolMessageType('FilePath', (_message.Message,), {
  'DESCRIPTOR' : _FILEPATH,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FilePath)
  })
_sym_db.RegisterMessage(FilePath)

FileInput = _reflection.GeneratedProtocolMessageType('FileInput', (_message.Message,), {
  'DESCRIPTOR' : _FILEINPUT,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FileInput)
  })
_sym_db.RegisterMessage(FileInput)

FileResults = _reflection.GeneratedProtocolMessageType('FileResults', (_message.Message,), {
  'DESCRIPTOR' : _FILERESULTS,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FileResults)
  })
_sym_db.RegisterMessage(FileResults)

AsFiles = _reflection.GeneratedProtocolMessageType('AsFiles', (_message.Message,), {
  'DESCRIPTOR' : _ASFILES,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.AsFiles)
  })
_sym_db.RegisterMessage(AsFiles)

TableConfig = _reflection.GeneratedProtocolMessageType('TableConfig', (_message.Message,), {
  'DESCRIPTOR' : _TABLECONFIG,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.TableConfig)
  })
_sym_db.RegisterMessage(TableConfig)

TableMetadata = _reflection.GeneratedProtocolMessageType('TableMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TABLEMETADATA,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.TableMetadata)
  })
_sym_db.RegisterMessage(TableMetadata)

PreparedFile = _reflection.GeneratedProtocolMessageType('PreparedFile', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDFILE,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PreparedFile)
  })
_sym_db.RegisterMessage(PreparedFile)

PreparedFileMetadata = _reflection.GeneratedProtocolMessageType('PreparedFileMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDFILEMETADATA,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PreparedFileMetadata)
  })
_sym_db.RegisterMessage(PreparedFileMetadata)

SlicePlan = _reflection.GeneratedProtocolMessageType('SlicePlan', (_message.Message,), {

  'PercentSlice' : _reflection.GeneratedProtocolMessageType('PercentSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEPLAN_PERCENTSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SlicePlan.PercentSlice)
    })
  ,

  'EntityKeysSlice' : _reflection.GeneratedProtocolMessageType('EntityKeysSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEPLAN_ENTITYKEYSSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SlicePlan.EntityKeysSlice)
    })
  ,
  'DESCRIPTOR' : _SLICEPLAN,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SlicePlan)
  })
_sym_db.RegisterMessage(SlicePlan)
_sym_db.RegisterMessage(SlicePlan.PercentSlice)
_sym_db.RegisterMessage(SlicePlan.EntityKeysSlice)

Uuid = _reflection.GeneratedProtocolMessageType('Uuid', (_message.Message,), {
  'DESCRIPTOR' : _UUID,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Uuid)
  })
_sym_db.RegisterMessage(Uuid)

SliceRequest = _reflection.GeneratedProtocolMessageType('SliceRequest', (_message.Message,), {

  'PercentSlice' : _reflection.GeneratedProtocolMessageType('PercentSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEREQUEST_PERCENTSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SliceRequest.PercentSlice)
    })
  ,

  'EntityKeysSlice' : _reflection.GeneratedProtocolMessageType('EntityKeysSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEREQUEST_ENTITYKEYSSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SliceRequest.EntityKeysSlice)
    })
  ,
  'DESCRIPTOR' : _SLICEREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SliceRequest)
  })
_sym_db.RegisterMessage(SliceRequest)
_sym_db.RegisterMessage(SliceRequest.PercentSlice)
_sym_db.RegisterMessage(SliceRequest.EntityKeysSlice)

Analysis = _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSIS,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Analysis)
  })
_sym_db.RegisterMessage(Analysis)

RequestDetails = _reflection.GeneratedProtocolMessageType('RequestDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDETAILS,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.RequestDetails)
  })
_sym_db.RegisterMessage(RequestDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\013CommonProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _FILETYPE._serialized_start=2223
  _FILETYPE._serialized_end=2302
  _PERENTITYBEHAVIOR._serialized_start=2305
  _PERENTITYBEHAVIOR._serialized_end=2460
  _FILEPATH._serialized_start=216
  _FILEPATH._serialized_end=329
  _FILEINPUT._serialized_start=331
  _FILEINPUT._serialized_end=424
  _FILERESULTS._serialized_start=426
  _FILERESULTS._serialized_end=525
  _ASFILES._serialized_start=527
  _ASFILES._serialized_end=600
  _TABLECONFIG._serialized_start=603
  _TABLECONFIG._serialized_end=848
  _TABLEMETADATA._serialized_start=850
  _TABLEMETADATA._serialized_end=953
  _PREPAREDFILE._serialized_start=956
  _PREPAREDFILE._serialized_end=1186
  _PREPAREDFILEMETADATA._serialized_start=1189
  _PREPAREDFILEMETADATA._serialized_end=1325
  _SLICEPLAN._serialized_start=1328
  _SLICEPLAN._serialized_end=1637
  _SLICEPLAN_PERCENTSLICE._serialized_start=1536
  _SLICEPLAN_PERCENTSLICE._serialized_end=1576
  _SLICEPLAN_ENTITYKEYSSLICE._serialized_start=1578
  _SLICEPLAN_ENTITYKEYSSLICE._serialized_end=1628
  _UUID._serialized_start=1639
  _UUID._serialized_end=1683
  _SLICEREQUEST._serialized_start=1686
  _SLICEREQUEST._serialized_end=1973
  _SLICEREQUEST_PERCENTSLICE._serialized_start=1536
  _SLICEREQUEST_PERCENTSLICE._serialized_end=1576
  _SLICEREQUEST_ENTITYKEYSSLICE._serialized_start=1914
  _SLICEREQUEST_ENTITYKEYSSLICE._serialized_end=1964
  _ANALYSIS._serialized_start=1976
  _ANALYSIS._serialized_end=2172
  _REQUESTDETAILS._serialized_start=2174
  _REQUESTDETAILS._serialized_end=2221
# @@protoc_insertion_point(module_scope)
