table.kda_table {
    border: 1px solid grey !important;
    border-collapse: collapse !important;
    border-spacing: 0 !important;
    font-size: 14px !important;
    margin-bottom: 6px !important;
}

table.kda_table table {
    margin-bottom: 0 !important;
}

.kda_table td, .kda_table th {
    border: 1px solid grey !important;
    border-collapse: collapse !important;
    padding: 6px !important;
    text-align: left !important;
    vertical-align: top !important;
}

.kda_table tr {
    background-color: inherit !important;
}

/* Style the tab */
.kda_tab {
    overflow: hidden;
    border-bottom: 1px solid grey;
    background-color: inherit;
}

/* Style the buttons that are used to open the tab content */
.kda_tab button {
    background-color: inherit;
    border-top: 1px solid grey;
    border-right: 1px solid grey;
    border-left: 1px solid grey;
    border-bottom: none;
    border-radius: 5px 5px 0px 0px;
    color: inherit;
    cursor: pointer;
    float: left;
    margin: 2px 8px 0px 2px;
    outline: none;
    padding: 5px 16px;
    transition: 0.3s;
}

/* Change background color of buttons on hover */
.kda_tab button:hover {
    background-color: grey;
}

/* Create an active/current tablink class */
.kda_tab button.kda_active {
    outline: 2px solid grey;
}

/* Style the tab content */
.kda_tabcontent {
    display: none;
    padding: 6px;
    border: 1px solid grey;
    border-top: none;
}

.kda_scroll_container {
    max-height: 400px;
    overflow: auto;
}
