# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/data_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0kaskada/kaskada/v1alpha/data_token_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$kaskada/kaskada/v1alpha/common.proto\"\x9b\x02\n\tDataToken\x12\'\n\rdata_token_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x61taTokenId\x12\x61\n\x0etable_versions\x18\x02 \x03(\x0b\x32\x35.kaskada.kaskada.v1alpha.DataToken.TableVersionsEntryB\x03\xe0\x41\x03R\rtableVersions\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x1a@\n\x12TableVersionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x03R\x05value:\x02\x38\x01\"9\n\x13GetDataTokenRequest\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\"\xab\x01\n\x14GetDataTokenResponse\x12\x41\n\ndata_token\x18\x01 \x01(\x0b\x32\".kaskada.kaskada.v1alpha.DataTokenR\tdataToken\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails2\xb0\x01\n\x10\x44\x61taTokenService\x12\x9b\x01\n\x0cGetDataToken\x12,.kaskada.kaskada.v1alpha.GetDataTokenRequest\x1a-.kaskada.kaskada.v1alpha.GetDataTokenResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1alpha/data_tokens/{data_token_id=*}B\x85\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x15\x44\x61taTokenServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_DATATOKEN = DESCRIPTOR.message_types_by_name['DataToken']
_DATATOKEN_TABLEVERSIONSENTRY = _DATATOKEN.nested_types_by_name['TableVersionsEntry']
_GETDATATOKENREQUEST = DESCRIPTOR.message_types_by_name['GetDataTokenRequest']
_GETDATATOKENRESPONSE = DESCRIPTOR.message_types_by_name['GetDataTokenResponse']
DataToken = _reflection.GeneratedProtocolMessageType('DataToken', (_message.Message,), {

  'TableVersionsEntry' : _reflection.GeneratedProtocolMessageType('TableVersionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATATOKEN_TABLEVERSIONSENTRY,
    '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DataToken.TableVersionsEntry)
    })
  ,
  'DESCRIPTOR' : _DATATOKEN,
  '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DataToken)
  })
_sym_db.RegisterMessage(DataToken)
_sym_db.RegisterMessage(DataToken.TableVersionsEntry)

GetDataTokenRequest = _reflection.GeneratedProtocolMessageType('GetDataTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetDataTokenRequest)
  })
_sym_db.RegisterMessage(GetDataTokenRequest)

GetDataTokenResponse = _reflection.GeneratedProtocolMessageType('GetDataTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetDataTokenResponse)
  })
_sym_db.RegisterMessage(GetDataTokenResponse)

_DATATOKENSERVICE = DESCRIPTOR.services_by_name['DataTokenService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\025DataTokenServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _DATATOKEN_TABLEVERSIONSENTRY._options = None
  _DATATOKEN_TABLEVERSIONSENTRY._serialized_options = b'8\001'
  _DATATOKEN.fields_by_name['data_token_id']._options = None
  _DATATOKEN.fields_by_name['data_token_id']._serialized_options = b'\340A\003'
  _DATATOKEN.fields_by_name['table_versions']._options = None
  _DATATOKEN.fields_by_name['table_versions']._serialized_options = b'\340A\003'
  _DATATOKEN.fields_by_name['create_time']._options = None
  _DATATOKEN.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _DATATOKENSERVICE.methods_by_name['GetDataToken']._options = None
  _DATATOKENSERVICE.methods_by_name['GetDataToken']._serialized_options = b'\202\323\344\223\002(\022&/v1alpha/data_tokens/{data_token_id=*}'
  _DATATOKEN._serialized_start=212
  _DATATOKEN._serialized_end=495
  _DATATOKEN_TABLEVERSIONSENTRY._serialized_start=431
  _DATATOKEN_TABLEVERSIONSENTRY._serialized_end=495
  _GETDATATOKENREQUEST._serialized_start=497
  _GETDATATOKENREQUEST._serialized_end=554
  _GETDATATOKENRESPONSE._serialized_start=557
  _GETDATATOKENRESPONSE._serialized_end=728
  _DATATOKENSERVICE._serialized_start=731
  _DATATOKENSERVICE._serialized_end=907
# @@protoc_insertion_point(module_scope)
